solve_in_place_scratch

Function solve_in_place_scratch 

pub fn solve_in_place_scratch<I: Index, T: ComplexField>(
    dim: usize,
    rhs_ncols: usize,
    par: Par,
) -> StackReq
computes the size and alignment of required workspace for solving a linear system defined by a matrix in place, given its bunch-kaufman decomposition