pub fn solve_in_place_with_conj<I: Index, T: ComplexField>(
L: MatRef<'_, T>,
diagonal: DiagRef<'_, T>,
subdiagonal: DiagRef<'_, T>,
conj_A: Conj,
perm: PermRef<'_, I>,
rhs: MatMut<'_, T>,
par: Par,
stack: &mut MemStack,
)Expand description
given the bunch-kaufman factors of a matrix $a$ and a matrix $b$ stored in rhs, this
function computes the solution of the linear system $A x = b$, implicitly conjugating $A$ if
needed
the solution of the linear system is stored in rhs
panics
- panics if
lb_factorsis not a square matrix - panics if
subdiagis not a column vector with the same number of rows as the dimension oflb_factors - panics if
rhsdoesn’t have the same number of rows as the dimension oflb_factors - panics if the provided memory in
stackis insufficient (seesolve_in_place_scratch)